@@ -138,8 +138,74 @@ def check_batch_size(config_dict):
         
     #image_resizer.HasField("fixed_shape_resizer"):
     
+def configure_learning_rate(configs, learning_rate=None, parameters={}):
+    keys = parameters.keys()
 
-    
+    if 'lr_type' in keys:
+        lr_type = parameters['lr_type']
+    else:
+        lr_type = 'constant_learning_rate'
+    if 'decay_steps' in keys:
+        decay_steps = parameters['decay_steps']
+    else:
+        decay_steps = None
+    if 'decay_factor' in keys:
+        decay_factor = parameters['decay_factor']
+    else:
+        decay_factor = None
+    if 'staircase' in keys:
+        staircase = parameters['staircase']
+    else:
+        staircase = True
+    if 'warmup_lr' in keys:
+        warmup_lr = parameters['warmup_lr']
+    else:
+        warmup_lr = None
+    if 'warmup_steps' in keys:
+        warmup_steps = parameters['warmup_steps']
+    else:
+        warmup_steps = None
+    if 'total_steps' in keys:
+        total_steps = parameters['total_steps']
+    else:
+        total_steps = None
+
+    optimizer_type = configs["train_config"].optimizer.WhichOneof("optimizer")
+    if optimizer_type == "rms_prop_optimizer":
+        optimizer_config = configs["train_config"].optimizer.rms_prop_optimizer
+    elif optimizer_type == "momentum_optimizer":
+        optimizer_config = configs["train_config"].optimizer.momentum_optimizer
+    elif optimizer_type == "adam_optimizer":
+        optimizer_config = configs["train_config"].optimizer.adam_optimizer
+    else:
+        raise TypeError("Optimizer %s is not supported." % optimizer_type)
+
+    print(optimizer_config)
+    if lr_type == "constant":
+        optimizer_config.learning_rate.constant_learning_rate.learning_rate = learning_rate
+        print(optimizer_config)
+    elif lr_type == "exponential_decay":
+        if decay_steps != None and decay_factor != None:
+            optimizer_config.learning_rate.exponential_decay_learning_rate.initial_learning_rate = learning_rate
+            optimizer_config.learning_rate.exponential_decay_learning_rate.decay_steps = decay_steps
+            optimizer_config.learning_rate.exponential_decay_learning_rate.decay_factor = decay_factor
+            optimizer_config.learning_rate.exponential_decay_learning_rate.staircase = staircase
+            print(optimizer_config)
+    elif lr_type == "manual_step":
+        optimizer_config.learning_rate["manual_step_learning_rate"] = {}
+        manual_lr = optimizer_config.learning_rate.manual_step_learning_rate
+        original_learning_rate = manual_lr.initial_learning_rate
+        learning_rate_scaling = float(learning_rate) / original_learning_rate
+        manual_lr.initial_learning_rate = learning_rate
+        for schedule in manual_lr.schedule:
+            schedule.learning_rate *= learning_rate_scaling
+        print(optimizer_config)
+    elif lr_type == "cosine_decay":
+        optimizer_config.learning_rate.cosine_decay_learning_rate.learning_rate_base = learning_rate
+        optimizer_config.learning_rate.cosine_decay_learning_rate.total_steps = total_steps
+        optimizer_config.learning_rate.cosine_decay_learning_rate.warmup_learning_rate = warmup_lr
+        optimizer_config.learning_rate.cosine_decay_learning_rate.warmup_steps = warmup_steps
+        print(optimizer_config)
 
 def set_image_resizer(config_dict, shape):
     '''
@@ -257,8 +323,9 @@ def set_variable_loader(config_dict, incremental_or_transfer, FromSratch=False):
 
 
 
-def edit_config(model_selected, input_config_dir, output_config_dir, num_steps, label_map_path, record_dir, eval_number, annotation_type, 
-                batch_size=None, learning_rate=None, resizer_size=None, incremental_or_transfer="transfer"):
+def edit_config(model_selected, input_config_dir, output_config_dir, num_steps, label_map_path, 
+                record_dir, eval_number, annotation_type, batch_size=None, learning_rate=None, 
+                parameters={}, resizer_size=None, incremental_or_transfer="transfer"):
     '''
         Wrapper to edit the essential values inside the base configuration protobuf file provided with an object-detection/segmentation checkpoint.
         This configuration file is what will entirely define your model, pre-processing, training, evaluation etc. It is the most important file of a model with the checkpoint file and should never be deleted. 
@@ -306,8 +373,8 @@ def edit_config(model_selected, input_config_dir, output_config_dir, num_steps,
                             eval_record_path=os.path.join(record_dir,"eval.record"))
 
     if learning_rate is not None:
-        config_util._update_initial_learning_rate(configs, learning_rate)
-
+        # config_util._update_initial_learning_rate(configs, learning_rate)
+        configure_learning_rate(configs, learning_rate, parameters)
     if batch_size is not None:
         config_util._update_batch_size(configs, batch_size)
     check_batch_size(configs)
